@@ -1,6 +1,8 @@
-from user.models import User
+from django.contrib.auth import get_user_model
 from ..utils import exceptions
 
+User = get_user_model()
+
 
 def login_required(resolver):
     def wrapper(parent, info, *args, **kwargs):
